bayespy.inference.vmp.nodes.dirichlet.DirichletDistribution.compute_message_to_parent
=====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.dirichlet

.. automethod:: DirichletDistribution.compute_message_to_parent